@@ -1,6 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2008 Sebastian Trueg <trueg@kde.org>
     SPDX-FileCopyrightText: 2009 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2025 Felix Ernst <felixernst@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,7 +12,8 @@
 #include <QString>
 #include <QWidget>
 
-class QLabel;
+class QPlainTextEdit;
+class QToolButton;
 
 /**
  * @brief Allows to edit and show a comment as part of KMetaDataWidget.
@@ -35,21 +37,15 @@ public:
     void setReadOnly(bool readOnly);
     bool isReadOnly() const;
 
-    QSize sizeHint() const override;
-
 Q_SIGNALS:
     void commentChanged(const QString &comment);
 
 protected:
     bool event(QEvent *event) override;
 
-private Q_SLOTS:
-    void slotLinkActivated(const QString &link);
-
 private:
-    bool m_readOnly = false;
-    QLabel *const m_label;
-    QLabel *const m_sizeHintHelper; // see comment in KCommentWidget::sizeHint()
+    QPlainTextEdit *const m_plainTextEdit;
+    QToolButton *const m_saveButton;
     QString m_comment;
 };
 
